pub enum CapGroupUpdateKey {
SetCap {
cap_group_id: CapGroupId,
},
SetRelativeCap {
cap_group_id: CapGroupId,
},
SetMembership {
market_id: TargetId,
},
}Expand description
Identifies a cap-group governance update for accept/revoke operations.
Variants
SetCap
Fields

cap_group_id: CapGroupIdSetRelativeCap
Fields

cap_group_id: CapGroupIdSetMembership
Fields

market_id: TargetIdTrait Implementations
Sourceimpl BorshDeserialize for CapGroupUpdateKey
impl BorshDeserialize for CapGroupUpdateKey
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for CapGroupUpdateKey
impl BorshSchema for CapGroupUpdateKey
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for CapGroupUpdateKey
impl BorshSerialize for CapGroupUpdateKey
Sourceimpl Clone for CapGroupUpdateKey
impl Clone for CapGroupUpdateKey
Sourcefn clone(&self) -> CapGroupUpdateKey
fn clone(&self) -> CapGroupUpdateKey
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapGroupUpdateKey
impl Debug for CapGroupUpdateKey
Sourceimpl<'de> Deserialize<'de> for CapGroupUpdateKey
impl<'de> Deserialize<'de> for CapGroupUpdateKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EnumExt for CapGroupUpdateKey
impl EnumExt for CapGroupUpdateKey
Sourceimpl From<&CapGroupUpdate> for CapGroupUpdateKey
impl From<&CapGroupUpdate> for CapGroupUpdateKey
Sourcefn from(value: &CapGroupUpdate) -> Self
fn from(value: &CapGroupUpdate) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for CapGroupUpdateKey
impl JsonSchema for CapGroupUpdateKey
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CapGroupUpdateKey
impl PartialEq for CapGroupUpdateKey
Sourceimpl Serialize for CapGroupUpdateKey
impl Serialize for CapGroupUpdateKey
impl Eq for CapGroupUpdateKey
impl StructuralPartialEq for CapGroupUpdateKey