pub struct CapGroupId(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl BorshDeserialize for CapGroupId
impl BorshDeserialize for CapGroupId
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for CapGroupId
impl BorshSchema for CapGroupId
Sourcefn declaration() -> Declaration
fn declaration() -> Declaration
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(
definitions: &mut BTreeMap<Declaration, Definition>,
)
fn add_definitions_recursively( definitions: &mut BTreeMap<Declaration, Definition>, )
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for CapGroupId
impl BorshSerialize for CapGroupId
Sourceimpl Clone for CapGroupId
impl Clone for CapGroupId
Sourcefn clone(&self) -> CapGroupId
fn clone(&self) -> CapGroupId
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapGroupId
impl Debug for CapGroupId
Sourceimpl<'de> Deserialize<'de> for CapGroupId
impl<'de> Deserialize<'de> for CapGroupId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for CapGroupId
impl Display for CapGroupId
Sourceimpl From<&str> for CapGroupId
impl From<&str> for CapGroupId
Sourceimpl From<CapGroupId> for String
impl From<CapGroupId> for String
Sourcefn from(value: CapGroupId) -> Self
fn from(value: CapGroupId) -> Self
Converts to this type from the input type.
Sourceimpl From<String> for CapGroupId
impl From<String> for CapGroupId
Sourceimpl Hash for CapGroupId
impl Hash for CapGroupId
Sourceimpl JsonSchema for CapGroupId
impl JsonSchema for CapGroupId
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for CapGroupId
impl Ord for CapGroupId
Sourcefn cmp(&self, other: &CapGroupId) -> Ordering
fn cmp(&self, other: &CapGroupId) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CapGroupId
impl PartialEq for CapGroupId
Sourceimpl PartialOrd for CapGroupId
impl PartialOrd for CapGroupId
Sourceimpl Serialize for CapGroupId
impl Serialize for CapGroupId
impl Eq for CapGroupId
impl StructuralPartialEq for CapGroupId