pub struct MarketLockSet {
pub locks: Vec<MarketLock>,
}Expand description
A set of market locks.
Fields
locks: Vec<MarketLock>Implementations
Sourceimpl MarketLockSet
impl MarketLockSet
Sourcepub fn filter_unlocked_targets(
&self,
targets: &[TargetId],
current_ns: u64,
) -> Vec<TargetId>
pub fn filter_unlocked_targets( &self, targets: &[TargetId], current_ns: u64, ) -> Vec<TargetId>
Filter a target list to only unlocked targets.
Sourcepub fn filter_allocation_plan(
&self,
plan: &[(TargetId, u128)],
current_ns: u64,
) -> Vec<(TargetId, u128)>
pub fn filter_allocation_plan( &self, plan: &[(TargetId, u128)], current_ns: u64, ) -> Vec<(TargetId, u128)>
Filter an allocation plan to only unlocked targets.
Sourcepub fn filter_supply_queue(
&self,
queue: &SupplyQueue,
current_ns: u64,
) -> SupplyQueue
pub fn filter_supply_queue( &self, queue: &SupplyQueue, current_ns: u64, ) -> SupplyQueue
Filter a supply queue to only unlocked targets.
Sourcepub fn filter_withdraw_route(
&self,
route: &WithdrawRoute,
current_ns: u64,
) -> Result<WithdrawRoute, WithdrawRouteError>
pub fn filter_withdraw_route( &self, route: &WithdrawRoute, current_ns: u64, ) -> Result<WithdrawRoute, WithdrawRouteError>
Filter a withdraw route to only unlocked targets.
Sourcepub fn build_allocation_plan_with_locks(
&self,
queue: &SupplyQueue,
current_ns: u64,
) -> Vec<(TargetId, u128)>
pub fn build_allocation_plan_with_locks( &self, queue: &SupplyQueue, current_ns: u64, ) -> Vec<(TargetId, u128)>
Build an allocation plan from a queue while excluding locked targets.
Sourcepub fn build_withdrawal_plan_with_locks(
&self,
route: &WithdrawRoute,
current_ns: u64,
) -> Result<Vec<(TargetId, u128)>, WithdrawRouteError>
pub fn build_withdrawal_plan_with_locks( &self, route: &WithdrawRoute, current_ns: u64, ) -> Result<Vec<(TargetId, u128)>, WithdrawRouteError>
Build a withdraw plan from a route while excluding locked targets.
Sourcepub fn build_refresh_plan_with_locks(
&self,
targets: &[TargetId],
current_ns: u64,
) -> Vec<TargetId>
pub fn build_refresh_plan_with_locks( &self, targets: &[TargetId], current_ns: u64, ) -> Vec<TargetId>
Build a refresh target list while excluding locked targets.
Sourceimpl MarketLockSet
impl MarketLockSet
pub fn new() -> Self
pub fn is_empty(&self) -> bool
pub fn len(&self) -> usize
pub fn active_count(&self, current_ns: u64) -> usize
pub fn is_all_expired(&self, current_ns: u64) -> bool
pub fn is_locked(&self, target_id: TargetId, current_ns: u64) -> bool
pub fn is_locked_by_op( &self, target_id: TargetId, op_id: u64, current_ns: u64, ) -> bool
pub fn get_lock( &self, target_id: TargetId, current_ns: u64, ) -> Option<&MarketLock>
Sourcepub fn acquire(
&self,
lock: MarketLock,
current_ns: u64,
) -> Result<Self, MarketLock>
pub fn acquire( &self, lock: MarketLock, current_ns: u64, ) -> Result<Self, MarketLock>
Acquire a lock, returning an updated lock set or the existing lock on conflict.
pub fn release(&self, target_id: TargetId) -> Self
Sourcepub fn release_by_op(&self, target_id: TargetId, op_id: u64) -> Self
pub fn release_by_op(&self, target_id: TargetId, op_id: u64) -> Self
Release a lock held by a specific operation.
Sourcepub fn release_all_by_op(&self, op_id: u64) -> Self
pub fn release_all_by_op(&self, op_id: u64) -> Self
Release all locks held by a specific operation.
Sourcepub fn cleanup_expired(&self, current_ns: u64) -> Self
pub fn cleanup_expired(&self, current_ns: u64) -> Self
Clean up expired locks.
Sourcepub fn locked_targets(&self, current_ns: u64) -> Vec<TargetId>
pub fn locked_targets(&self, current_ns: u64) -> Vec<TargetId>
Get all currently locked target IDs.
Sourcepub fn find_locked_targets(
&self,
targets: &[TargetId],
current_ns: u64,
) -> Vec<TargetId>
pub fn find_locked_targets( &self, targets: &[TargetId], current_ns: u64, ) -> Vec<TargetId>
Check if any of the targets in a list are locked.