pub fn build_refresh_plan_from_targets(
targets: &[TargetId],
cooldown_ns: u64,
last_refresh_ns: u64,
) -> Result<RefreshPlan, RefreshPlanError>Expand description
Build and validate a refresh plan from target IDs.
pub fn build_refresh_plan_from_targets(
targets: &[TargetId],
cooldown_ns: u64,
last_refresh_ns: u64,
) -> Result<RefreshPlan, RefreshPlanError>Build and validate a refresh plan from target IDs.