pub fn handle_payout_failure_default(
state: &PayoutState,
failure_reason: impl Into<String>,
) -> RecoveryOutcomeExpand description
Handle a failed payout operation using the payout amount as the idle restore value.
pub fn handle_payout_failure_default(
state: &PayoutState,
failure_reason: impl Into<String>,
) -> RecoveryOutcomeHandle a failed payout operation using the payout amount as the idle restore value.